==> haskell-drbg-0.5.5-134-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-drbg.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 DRBG
version:              0.5.5
visibility:           public
id:                   DRBG-0.5.5-GM4P8fsyS7RE5RT5CMW23t
key:                  DRBG-0.5.5-GM4P8fsyS7RE5RT5CMW23t
license:              BSD-3-Clause
maintainer:           Thomas DuBuisson
author:               Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability:            stable
synopsis:
    Deterministic random bit generator (aka RNG, PRNG) based
    HMACs, Hashes, and Ciphers.

description:          Cryptographically secure RNGs
category:             Cryptography
abi:                  7c04e0a71ff04424e6172e2600fb7621
exposed:              True
exposed-modules:
    Crypto.Random.DRBG Crypto.Random.DRBG.CTR Crypto.Random.DRBG.HMAC
    Crypto.Random.DRBG.Hash Crypto.Random.DRBG.Types

hidden-modules:       Crypto.Random.DRBG.HashDF
import-dirs:          /usr/lib/ghc-8.10.3/site-local/DRBG-0.5.5
library-dirs:         /usr/lib/ghc-8.10.3/site-local/DRBG-0.5.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/DRBG-0.5.5
hs-libraries:         HSDRBG-0.5.5-GM4P8fsyS7RE5RT5CMW23t
depends:
    base-4.14.1.0 bytestring-0.10.12.0
    cereal-0.5.8.1-GAgNOTi0dTnED5BVJ0WdTc
    cipher-aes128-0.7.0.5-45dIkq17XrB3htDFA9D5Vz
    crypto-api-0.13.3-29xf6phcoYS3UxI8fy8p1u
    cryptohash-cryptoapi-0.1.4-5WnXU5lp9keAqL03CeCH5V
    entropy-0.4.1.6-6Z0sejCw1fy7sJ1AU1oQ6y mtl-2.2.2
    parallel-3.2.2.0-HTf2o2horULDwL7cXUB9uv
    prettyclass-1.0.0.0-FKRh4s9QhhBDCk8hIvEict
    tagged-0.8.6.1-A3E8I7zg2qBFE9O5vQsg6C

haddock-interfaces:   /usr/share/doc/haskell-drbg/html/DRBG.haddock
haddock-html:         /usr/share/doc/haskell-drbg/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-drbg-0.5.5-141-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-drbg.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 DRBG
version:              0.5.5
visibility:           public
id:                   DRBG-0.5.5-ACojJDg4QKtGg6etd0zzWm
key:                  DRBG-0.5.5-ACojJDg4QKtGg6etd0zzWm
license:              BSD-3-Clause
maintainer:           Thomas DuBuisson
author:               Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability:            stable
synopsis:
    Deterministic random bit generator (aka RNG, PRNG) based
    HMACs, Hashes, and Ciphers.

description:          Cryptographically secure RNGs
category:             Cryptography
abi:                  519760a0cb33ef22905efe22e28c3856
exposed:              True
exposed-modules:
    Crypto.Random.DRBG Crypto.Random.DRBG.CTR Crypto.Random.DRBG.HMAC
    Crypto.Random.DRBG.Hash Crypto.Random.DRBG.Types

hidden-modules:       Crypto.Random.DRBG.HashDF
import-dirs:          /usr/lib/ghc-8.10.3/site-local/DRBG-0.5.5
library-dirs:         /usr/lib/ghc-8.10.3/site-local/DRBG-0.5.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/DRBG-0.5.5
hs-libraries:         HSDRBG-0.5.5-ACojJDg4QKtGg6etd0zzWm
depends:
    base-4.14.1.0 bytestring-0.10.12.0
    cereal-0.5.8.1-GAgNOTi0dTnED5BVJ0WdTc
    cipher-aes128-0.7.0.5-45dIkq17XrB3htDFA9D5Vz
    crypto-api-0.13.3-29xf6phcoYS3UxI8fy8p1u
    cryptohash-cryptoapi-0.1.4-4DVRv4u734h4jVoGUv1wlG
    entropy-0.4.1.6-6Z0sejCw1fy7sJ1AU1oQ6y mtl-2.2.2
    parallel-3.2.2.0-HTf2o2horULDwL7cXUB9uv
    prettyclass-1.0.0.0-FKRh4s9QhhBDCk8hIvEict
    tagged-0.8.6.1-A3E8I7zg2qBFE9O5vQsg6C

haddock-interfaces:   /usr/share/doc/haskell-drbg/html/DRBG.haddock
haddock-html:         /usr/share/doc/haskell-drbg/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
